@@ -2,9 +2,9 @@ import os
 import numpy as np
 import cifti
 from pandas import DataFrame
-
 from neuro_helper.template import get_template
 from neuro_helper.entity import TemplateName, Space
+import pandas_flavor as pf
 
 
 def out_of(name, dir_from_last_part=True):
@@ -32,7 +32,9 @@ def out_of(name, dir_from_last_part=True):
     return file
 
 
-def find_shared_subjects(find_files, prepare_file_content, template_name: TemplateName, space: Space, tasks, return_indices):
+def find_shared_subjects(find_files, prepare_file_content,
+                         template_name: TemplateName, space: Space,
+                         tasks, return_indices):
     all_ids = []
     subject_id_dict = {}
     for task in tasks:
@@ -55,7 +57,7 @@ def find_shared_subjects(find_files, prepare_file_content, template_name: Templa
 
 
 def generate_long_data(find_files, prepare_file_content, template_name: TemplateName, space: Space):
-    mask, unique_networks, networks, regions, _ = get_template(template_name)
+    mask, unique_networks, networks, regions, _ = get_template(template_name, space)
     long_data = None
     for task in ["Rest", "StoryM", "Motort", "Wrkmem"]:
         files = find_files(task=task, template_name=template_name, space=space)
@@ -81,6 +83,7 @@ def generate_long_data(find_files, prepare_file_content, template_name: Template
     return df
 
 
+@pf.register_dataframe_method
 def build_single_topo_map(df: DataFrame, template_name: TemplateName, space: Space):
     """
     :param df: must only contains two columns: regions and values
@@ -101,4 +104,4 @@ def build_single_topo_map(df: DataFrame, template_name: TemplateName, space: Spa
 
 def combine_topo_map(topo_maps):
     topos, brains = list(zip(*topo_maps))
-    return np.concatenate(topos, axis=0), brains[0], cifti.Series(0, 1, len(topo_maps))
\ No newline at end of file
+    return np.concatenate(topos, axis=0), brains[0], cifti.Series(0, 1, len(topo_maps))
